@@ -188,6 +188,7 @@ class Scope:
         "_extras",
         "_breadcrumbs",
         "_n_breadcrumbs_truncated",
+        "_gen_ai_original_message_count",
         "_event_processors",
         "_error_processors",
         "_should_capture",
@@ -213,6 +214,7 @@ class Scope:
         self._name = None  # type: Optional[str]
         self._propagation_context = None  # type: Optional[PropagationContext]
         self._n_breadcrumbs_truncated = 0  # type: int
+        self._gen_ai_original_message_count = {}  # type: Dict[str, int]
 
         self.client = NonRecordingClient()  # type: sentry_sdk.client.BaseClient
 
@@ -247,6 +249,7 @@ class Scope:
 
         rv._breadcrumbs = copy(self._breadcrumbs)
         rv._n_breadcrumbs_truncated = self._n_breadcrumbs_truncated
+        rv._gen_ai_original_message_count = self._gen_ai_original_message_count.copy()
         rv._event_processors = self._event_processors.copy()
         rv._error_processors = self._error_processors.copy()
         rv._propagation_context = self._propagation_context
@@ -1583,6 +1586,10 @@ class Scope:
             self._n_breadcrumbs_truncated = (
                 self._n_breadcrumbs_truncated + scope._n_breadcrumbs_truncated
             )
+        if scope._gen_ai_original_message_count:
+            self._gen_ai_original_message_count.update(
+                scope._gen_ai_original_message_count
+            )
         if scope._span:
             self._span = scope._span
         if scope._attachments:
@@ -1679,7 +1686,7 @@ def new_scope():
         try:
             # restore original scope
             _current_scope.reset(token)
-        except LookupError:
+        except (LookupError, ValueError):
             capture_internal_exception(sys.exc_info())
 
 
@@ -1717,7 +1724,7 @@ def use_scope(scope):
         try:
             # restore original scope
             _current_scope.reset(token)
-        except LookupError:
+        except (LookupError, ValueError):
             capture_internal_exception(sys.exc_info())
 
 
@@ -1761,12 +1768,12 @@ def isolation_scope():
         # restore original scopes
         try:
             _current_scope.reset(current_token)
-        except LookupError:
+        except (LookupError, ValueError):
             capture_internal_exception(sys.exc_info())
 
         try:
             _isolation_scope.reset(isolation_token)
-        except LookupError:
+        except (LookupError, ValueError):
             capture_internal_exception(sys.exc_info())
 
 
@@ -1808,12 +1815,12 @@ def use_isolation_scope(isolation_scope):
         # restore original scopes
         try:
             _current_scope.reset(current_token)
-        except LookupError:
+        except (LookupError, ValueError):
             capture_internal_exception(sys.exc_info())
 
         try:
             _isolation_scope.reset(isolation_token)
-        except LookupError:
+        except (LookupError, ValueError):
             capture_internal_exception(sys.exc_info())
 
 
